import express, { Request, Response } from "express";
import {
  createMember,
  deleteMemberById,
  getAllMembers,
  getMemberById,
  getMembersByIds,
  updateMemberById,
} from "../../../controller/admin/configuration/memberController";
import PermissionHelper from "../../../helpers/permissionHelper";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllMembers(req, res);
});

router.post("/ids", async (req: Request, res: Response) => {
  await getMembersByIds(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getMemberById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "operation", "force"),
  async (req: Request, res: Response) => {
    await createMember(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "operation", "force"),
  async (req: Request, res: Response) => {
    await updateMemberById(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "operation", "force"),
  async (req: Request, res: Response) => {
    await deleteMemberById(req, res);
  }
);

export default router;
