import express from "express";
import PermissionHelper from "../../helpers/permissionHelper";

import member from "./configuration/member";

import role from "./management/role";
import user from "./management/user";
import invite from "./management/invite";
import backup from "./management/backup";

var router = express.Router({ mergeParams: true });

router.use("/member", PermissionHelper.passCheckMiddleware("read", "configuration", "force"), member);

router.use("/role", PermissionHelper.passCheckMiddleware("read", "management", "role"), role);
router.use(
  "/user",
  PermissionHelper.passCheckSomeMiddleware([
    { requiredPermissions: "read", section: "management", module: "user" },
    { requiredPermissions: "read", section: "management", module: "role" },
  ]),
  user
);
router.use("/invite", PermissionHelper.passCheckMiddleware("read", "management", "user"), invite);
router.use("/backup", PermissionHelper.passCheckMiddleware("read", "management", "backup"), backup);

export default router;
